@@ -79,7 +79,11 @@
     if( inherits(i, 'sk') ) i = as.logical(i[])
 
     # handle empty gval
-    if( is.null(x[['gval']]) ) return( rep(NA_real_, length(i)) )
+    if( is.null(x[['gval']]) ) {
+
+      if( is.logical(i) ) return( rep(NA_real_, sum(i)) )
+      return( rep(NA_real_, length(i)) )
+    }
 
     # numeric indices are for the vectorized grid values
     if( !is_multi )
@@ -552,7 +556,7 @@ anyNA.sk = function(x, recursive)
 
   # check the pre-computed NAs index or tell the user to validate
   if(is.null(x[['is_obs']])) stop('invalid sk object. Pass it to sk_validate first')
-  return(all(x[['is_obs']]))
+  return(!all(x[['is_obs']]))
 }
 
 #' Calculate the mean value in a grid
